========
Valves
========

Pneumatic Valve
---------------

.. autoclass:: pcdswidgets.vacuum.valves.PneumaticValve
   :members:

Pneumatic Valve - NO
--------------------

.. autoclass:: pcdswidgets.vacuum.valves.PneumaticValveNO
   :members:

Pneumatic Valve - DA
--------------------

.. autoclass:: pcdswidgets.vacuum.valves.PneumaticValveDA
   :members:

Aperture Valve
--------------

.. autoclass:: pcdswidgets.vacuum.valves.ApertureValve
   :members:

Fast Shutter
------------

.. autoclass:: pcdswidgets.vacuum.valves.FastShutter
   :members:

Needle Valve
------------

.. autoclass:: pcdswidgets.vacuum.valves.NeedleValve
   :members:

Proportional Valve
------------------

.. autoclass:: pcdswidgets.vacuum.valves.ProportionalValve
   :members:

Right Angle Manual Valve
------------------------

.. autoclass:: pcdswidgets.vacuum.valves.RightAngleManualValve
   :members:

Control Valve
-------------

.. autoclass:: pcdswidgets.vacuum.valves.ControlValve
   :members:

Control Only Valve (Normally Closed)
------------------------------------

.. autoclass:: pcdswidgets.vacuum.valves.ControlOnlyValveNC
   :members:

Control Only Valve (Normally Open)
------------------------------------

.. autoclass:: pcdswidgets.vacuum.valves.ControlOnlyValveNO
   :members:
